Class: Google::Apis::CloudidentityV1::DynamicGroupMetadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1::DynamicGroupMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb
Overview
Dynamic group metadata like queries and status.
Instance Attribute Summary collapse
-
#queries ⇒ Array<Google::Apis::CloudidentityV1::DynamicGroupQuery>
Memberships will be the union of all queries.
-
#status ⇒ Google::Apis::CloudidentityV1::DynamicGroupStatus
The current status of a dynamic group along with timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DynamicGroupMetadata
constructor
A new instance of DynamicGroupMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DynamicGroupMetadata
Returns a new instance of DynamicGroupMetadata.
302 303 304 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#queries ⇒ Array<Google::Apis::CloudidentityV1::DynamicGroupQuery>
Memberships will be the union of all queries. Only one entry with USER
resource is currently supported. Customers can create up to 500 dynamic groups.
Corresponds to the JSON property queries
295 296 297 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 295 def queries @queries end |
#status ⇒ Google::Apis::CloudidentityV1::DynamicGroupStatus
The current status of a dynamic group along with timestamp.
Corresponds to the JSON property status
300 301 302 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 300 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
307 308 309 310 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 307 def update!(**args) @queries = args[:queries] if args.key?(:queries) @status = args[:status] if args.key?(:status) end |