Class: Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1BrowserAttributes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb

Overview

Contains information about browser profiles reported by the Endpoint Verification extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1BrowserAttributes

Returns a new instance of GoogleAppsCloudidentityDevicesV1BrowserAttributes.



679
680
681
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chrome_browser_infoGoogle::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1BrowserInfo

Browser-specific fields reported by the Endpoint Verification extension. Corresponds to the JSON property chromeBrowserInfo



665
666
667
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 665

def chrome_browser_info
  @chrome_browser_info
end

#chrome_profile_idString

Chrome profile ID that is exposed by the Chrome API. It is unique for each device. Corresponds to the JSON property chromeProfileId

Returns:

  • (String)


671
672
673
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 671

def chrome_profile_id
  @chrome_profile_id
end

#last_profile_sync_timeString

Timestamp in milliseconds since the Unix epoch when the profile/gcm id was last synced. Corresponds to the JSON property lastProfileSyncTime

Returns:

  • (String)


677
678
679
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 677

def last_profile_sync_time
  @last_profile_sync_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



684
685
686
687
688
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 684

def update!(**args)
  @chrome_browser_info = args[:chrome_browser_info] if args.key?(:chrome_browser_info)
  @chrome_profile_id = args[:chrome_profile_id] if args.key?(:chrome_profile_id)
  @last_profile_sync_time = args[:last_profile_sync_time] if args.key?(:last_profile_sync_time)
end