Class: Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1BrowserInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb

Overview

Browser-specific fields reported by the Endpoint Verification extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1BrowserInfo

Returns a new instance of GoogleAppsCloudidentityDevicesV1BrowserInfo.



795
796
797
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#browser_management_stateString

Output only. Browser's management state. Corresponds to the JSON property browserManagementState

Returns:

  • (String)


700
701
702
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 700

def browser_management_state
  @browser_management_state
end

#browser_versionString

Version of the request initiating browser. E.g. 91.0.4442.4. Corresponds to the JSON property browserVersion

Returns:

  • (String)


705
706
707
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 705

def browser_version
  @browser_version
end

#is_built_in_dns_client_enabledBoolean Also known as: is_built_in_dns_client_enabled?

Current state of built-in DNS client. Corresponds to the JSON property isBuiltInDnsClientEnabled

Returns:

  • (Boolean)


711
712
713
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 711

def is_built_in_dns_client_enabled
  @is_built_in_dns_client_enabled
end

#is_bulk_data_entry_analysis_enabledBoolean Also known as: is_bulk_data_entry_analysis_enabled?

Current state of [bulk data analysis](https://chromeenterprise.google/policies/

OnBulkDataEntryEnterpriseConnector). Set to true if provider list from Chrome

is non-empty. Corresponds to the JSON property isBulkDataEntryAnalysisEnabled

Returns:

  • (Boolean)


719
720
721
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 719

def is_bulk_data_entry_analysis_enabled
  @is_bulk_data_entry_analysis_enabled
end

#is_chrome_cleanup_enabledBoolean Also known as: is_chrome_cleanup_enabled?

Deprecated: This field is not used for Chrome version 118 and later. Current state of Chrome Cleanup. Corresponds to the JSON property isChromeCleanupEnabled

Returns:

  • (Boolean)


727
728
729
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 727

def is_chrome_cleanup_enabled
  @is_chrome_cleanup_enabled
end

#is_chrome_remote_desktop_app_blockedBoolean Also known as: is_chrome_remote_desktop_app_blocked?

Current state of Chrome Remote Desktop app. Corresponds to the JSON property isChromeRemoteDesktopAppBlocked

Returns:

  • (Boolean)


734
735
736
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 734

def is_chrome_remote_desktop_app_blocked
  @is_chrome_remote_desktop_app_blocked
end

#is_file_download_analysis_enabledBoolean Also known as: is_file_download_analysis_enabled?

Current state of file download analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isFileDownloadAnalysisEnabled

Returns:

  • (Boolean)


742
743
744
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 742

def is_file_download_analysis_enabled
  @is_file_download_analysis_enabled
end

#is_file_upload_analysis_enabledBoolean Also known as: is_file_upload_analysis_enabled?

Current state of file upload analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isFileUploadAnalysisEnabled

Returns:

  • (Boolean)


750
751
752
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 750

def is_file_upload_analysis_enabled
  @is_file_upload_analysis_enabled
end

#is_realtime_url_check_enabledBoolean Also known as: is_realtime_url_check_enabled?

Current state of real-time URL check. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isRealtimeUrlCheckEnabled

Returns:

  • (Boolean)


758
759
760
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 758

def is_realtime_url_check_enabled
  @is_realtime_url_check_enabled
end

#is_security_event_analysis_enabledBoolean Also known as: is_security_event_analysis_enabled?

Current state of security event analysis. Set to true if provider list from Chrome is non-empty. Corresponds to the JSON property isSecurityEventAnalysisEnabled

Returns:

  • (Boolean)


766
767
768
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 766

def is_security_event_analysis_enabled
  @is_security_event_analysis_enabled
end

#is_site_isolation_enabledBoolean Also known as: is_site_isolation_enabled?

Current state of site isolation. Corresponds to the JSON property isSiteIsolationEnabled

Returns:

  • (Boolean)


773
774
775
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 773

def is_site_isolation_enabled
  @is_site_isolation_enabled
end

#is_third_party_blocking_enabledBoolean Also known as: is_third_party_blocking_enabled?

Current state of third-party blocking. Corresponds to the JSON property isThirdPartyBlockingEnabled

Returns:

  • (Boolean)


780
781
782
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 780

def is_third_party_blocking_enabled
  @is_third_party_blocking_enabled
end

#password_protection_warning_triggerString

Current state of password protection trigger. Corresponds to the JSON property passwordProtectionWarningTrigger

Returns:

  • (String)


787
788
789
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 787

def password_protection_warning_trigger
  @password_protection_warning_trigger
end

#safe_browsing_protection_levelString

Current state of Safe Browsing protection level. Corresponds to the JSON property safeBrowsingProtectionLevel

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 793

def safe_browsing_protection_level
  @safe_browsing_protection_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 800

def update!(**args)
  @browser_management_state = args[:browser_management_state] if args.key?(:browser_management_state)
  @browser_version = args[:browser_version] if args.key?(:browser_version)
  @is_built_in_dns_client_enabled = args[:is_built_in_dns_client_enabled] if args.key?(:is_built_in_dns_client_enabled)
  @is_bulk_data_entry_analysis_enabled = args[:is_bulk_data_entry_analysis_enabled] if args.key?(:is_bulk_data_entry_analysis_enabled)
  @is_chrome_cleanup_enabled = args[:is_chrome_cleanup_enabled] if args.key?(:is_chrome_cleanup_enabled)
  @is_chrome_remote_desktop_app_blocked = args[:is_chrome_remote_desktop_app_blocked] if args.key?(:is_chrome_remote_desktop_app_blocked)
  @is_file_download_analysis_enabled = args[:is_file_download_analysis_enabled] if args.key?(:is_file_download_analysis_enabled)
  @is_file_upload_analysis_enabled = args[:is_file_upload_analysis_enabled] if args.key?(:is_file_upload_analysis_enabled)
  @is_realtime_url_check_enabled = args[:is_realtime_url_check_enabled] if args.key?(:is_realtime_url_check_enabled)
  @is_security_event_analysis_enabled = args[:is_security_event_analysis_enabled] if args.key?(:is_security_event_analysis_enabled)
  @is_site_isolation_enabled = args[:is_site_isolation_enabled] if args.key?(:is_site_isolation_enabled)
  @is_third_party_blocking_enabled = args[:is_third_party_blocking_enabled] if args.key?(:is_third_party_blocking_enabled)
  @password_protection_warning_trigger = args[:password_protection_warning_trigger] if args.key?(:password_protection_warning_trigger)
  @safe_browsing_protection_level = args[:safe_browsing_protection_level] if args.key?(:safe_browsing_protection_level)
end