Class: Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1ClientState
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1ClientState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb
Overview
Represents the state associated with an API client calling the Devices API. Resource representing ClientState and supports updates from API users
Instance Attribute Summary collapse
-
#asset_tags ⇒ Array<String>
The caller can specify asset tags for this resource Corresponds to the JSON property
assetTags. -
#compliance_state ⇒ String
The compliance state of the resource as specified by the API client.
-
#create_time ⇒ String
Output only.
-
#custom_id ⇒ String
This field may be used to store a unique identifier for the API resource within which these CustomAttributes are a field.
-
#etag ⇒ String
The token that needs to be passed back for concurrency control in updates.
-
#health_score ⇒ String
The Health score of the resource.
-
#key_value_pairs ⇒ Hash<String,Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1CustomAttributeValue>
The map of key-value attributes stored by callers specific to a device.
-
#last_update_time ⇒ String
Output only.
-
#managed ⇒ String
The management state of the resource as specified by the API client.
-
#name ⇒ String
Output only.
-
#owner_type ⇒ String
Output only.
-
#score_reason ⇒ String
A descriptive cause of the health score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1ClientState
constructor
A new instance of GoogleAppsCloudidentityDevicesV1ClientState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1ClientState
Returns a new instance of GoogleAppsCloudidentityDevicesV1ClientState.
1114 1115 1116 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_tags ⇒ Array<String>
The caller can specify asset tags for this resource
Corresponds to the JSON property assetTags
1038 1039 1040 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1038 def @asset_tags end |
#compliance_state ⇒ String
The compliance state of the resource as specified by the API client.
Corresponds to the JSON property complianceState
1043 1044 1045 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1043 def compliance_state @compliance_state end |
#create_time ⇒ String
Output only. The time the client state data was created.
Corresponds to the JSON property createTime
1048 1049 1050 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1048 def create_time @create_time end |
#custom_id ⇒ String
This field may be used to store a unique identifier for the API resource
within which these CustomAttributes are a field.
Corresponds to the JSON property customId
1054 1055 1056 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1054 def custom_id @custom_id end |
#etag ⇒ String
The token that needs to be passed back for concurrency control in updates.
Token needs to be passed back in UpdateRequest
Corresponds to the JSON property etag
1060 1061 1062 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1060 def etag @etag end |
#health_score ⇒ String
The Health score of the resource. The Health score is the callers
specification of the condition of the device from a usability point of view.
For example, a third-party device management provider may specify a health
score based on its compliance with organizational policies.
Corresponds to the JSON property healthScore
1068 1069 1070 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1068 def health_score @health_score end |
#key_value_pairs ⇒ Hash<String,Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1CustomAttributeValue>
The map of key-value attributes stored by callers specific to a device. The
total serialized length of this map may not exceed 10KB. No limit is placed on
the number of attributes in a map.
Corresponds to the JSON property keyValuePairs
1075 1076 1077 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1075 def key_value_pairs @key_value_pairs end |
#last_update_time ⇒ String
Output only. The time the client state data was last updated.
Corresponds to the JSON property lastUpdateTime
1080 1081 1082 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1080 def last_update_time @last_update_time end |
#managed ⇒ String
The management state of the resource as specified by the API client.
Corresponds to the JSON property managed
1085 1086 1087 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1085 def managed @managed end |
#name ⇒ String
Output only. Resource name of the ClientState in format: devices/device/deviceUsers/
device_user/clientState/partner, where partner corresponds to the partner
storing the data. For partners belonging to the "BeyondCorp Alliance", this is
the partner ID specified to you by Google. For all other callers, this is a
string of the form:customer-suffix, where customer is your customer ID.
The suffix is any string the caller specifies. This string will be displayed
verbatim in the administration console. This suffix is used in setting up
Custom Access Levels in Context-Aware Access. Your organization's customer ID
can be obtained from the URL: GET https://www.googleapis.com/admin/directory/
v1/customers/my_customer The id field in the response contains the customer
ID starting with the letter 'C'. The customer ID to be used in this API is the
string after the letter 'C' (not including 'C')
Corresponds to the JSON property name
1102 1103 1104 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1102 def name @name end |
#owner_type ⇒ String
Output only. The owner of the ClientState
Corresponds to the JSON property ownerType
1107 1108 1109 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1107 def owner_type @owner_type end |
#score_reason ⇒ String
A descriptive cause of the health score.
Corresponds to the JSON property scoreReason
1112 1113 1114 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1112 def score_reason @score_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1119 def update!(**args) @asset_tags = args[:asset_tags] if args.key?(:asset_tags) @compliance_state = args[:compliance_state] if args.key?(:compliance_state) @create_time = args[:create_time] if args.key?(:create_time) @custom_id = args[:custom_id] if args.key?(:custom_id) @etag = args[:etag] if args.key?(:etag) @health_score = args[:health_score] if args.key?(:health_score) @key_value_pairs = args[:key_value_pairs] if args.key?(:key_value_pairs) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @managed = args[:managed] if args.key?(:managed) @name = args[:name] if args.key?(:name) @owner_type = args[:owner_type] if args.key?(:owner_type) @score_reason = args[:score_reason] if args.key?(:score_reason) end |