Class: Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1DeviceUser

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb

Overview

Represents a user's use of a Device in the Cloud Identity Devices API. A DeviceUser is a resource representing a user's use of a Device

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1DeviceUser

Returns a new instance of GoogleAppsCloudidentityDevicesV1DeviceUser.



1484
1485
1486
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compromised_stateString

Compromised State of the DeviceUser object Corresponds to the JSON property compromisedState

Returns:

  • (String)


1434
1435
1436
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1434

def compromised_state
  @compromised_state
end

#create_timeString

When the user first signed in to the device Corresponds to the JSON property createTime

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1439

def create_time
  @create_time
end

#first_sync_timeString

Output only. Most recent time when user registered with this service. Corresponds to the JSON property firstSyncTime

Returns:

  • (String)


1444
1445
1446
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1444

def first_sync_time
  @first_sync_time
end

#language_codeString

Output only. Default locale used on device, in IETF BCP-47 format. Corresponds to the JSON property languageCode

Returns:

  • (String)


1449
1450
1451
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1449

def language_code
  @language_code
end

#last_sync_timeString

Output only. Last time when user synced with policies. Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


1454
1455
1456
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1454

def last_sync_time
  @last_sync_time
end

#management_stateString

Output only. Management state of the user on the device. Corresponds to the JSON property managementState

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1459

def management_state
  @management_state
end

#nameString

Output only. Resource name of the DeviceUser in format: devices/device/deviceUsers/ device_user`, wheredevice_useruniquely identifies a user's use of a device. Corresponds to the JSON propertyname`

Returns:

  • (String)


1467
1468
1469
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1467

def name
  @name
end

#password_stateString

Password state of the DeviceUser object Corresponds to the JSON property passwordState

Returns:

  • (String)


1472
1473
1474
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1472

def password_state
  @password_state
end

#user_agentString

Output only. User agent on the device for this specific user Corresponds to the JSON property userAgent

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1477

def user_agent
  @user_agent
end

#user_emailString

Email address of the user registered on the device. Corresponds to the JSON property userEmail

Returns:

  • (String)


1482
1483
1484
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1482

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1489

def update!(**args)
  @compromised_state = args[:compromised_state] if args.key?(:compromised_state)
  @create_time = args[:create_time] if args.key?(:create_time)
  @first_sync_time = args[:first_sync_time] if args.key?(:first_sync_time)
  @language_code = args[:language_code] if args.key?(:language_code)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @management_state = args[:management_state] if args.key?(:management_state)
  @name = args[:name] if args.key?(:name)
  @password_state = args[:password_state] if args.key?(:password_state)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @user_email = args[:user_email] if args.key?(:user_email)
end