Class: Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1WipeDeviceRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1WipeDeviceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb
Overview
Request message for wiping all data on the device.
Instance Attribute Summary collapse
-
#customer ⇒ String
Optional.
-
#remove_reset_lock ⇒ Boolean
(also: #remove_reset_lock?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1WipeDeviceRequest
constructor
A new instance of GoogleAppsCloudidentityDevicesV1WipeDeviceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1WipeDeviceRequest
Returns a new instance of GoogleAppsCloudidentityDevicesV1WipeDeviceRequest.
1740 1741 1742 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer ⇒ String
Optional. Resource name
of the customer. If you're using this API for your own organization, use
customers/my_customer If you're using this API to manage another organization,
use customers/customer`, where customer is the customer to whom the device
belongs.
Corresponds to the JSON propertycustomer`
1728 1729 1730 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1728 def customer @customer end |
#remove_reset_lock ⇒ Boolean Also known as: remove_reset_lock?
Optional. Specifies if a user is able to factory reset a device after a Device
Wipe. On iOS, this is called "Activation Lock", while on Android, this is
known as "Factory Reset Protection". If true, this protection will be removed
from the device, so that a user can successfully factory reset. If false, the
setting is untouched on the device.
Corresponds to the JSON property removeResetLock
1737 1738 1739 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1737 def remove_reset_lock @remove_reset_lock end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1745 1746 1747 1748 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1745 def update!(**args) @customer = args[:customer] if args.key?(:customer) @remove_reset_lock = args[:remove_reset_lock] if args.key?(:remove_reset_lock) end |