Class: Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1WipeDeviceUserResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb

Overview

Response message for wiping the user's account from the device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1WipeDeviceUserResponse

Returns a new instance of GoogleAppsCloudidentityDevicesV1WipeDeviceUserResponse.



1818
1819
1820
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_userGoogle::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1DeviceUser

Represents a user's use of a Device in the Cloud Identity Devices API. A DeviceUser is a resource representing a user's use of a Device Corresponds to the JSON property deviceUser



1816
1817
1818
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1816

def device_user
  @device_user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1823
1824
1825
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1823

def update!(**args)
  @device_user = args[:device_user] if args.key?(:device_user)
end