Class: Google::Apis::CloudidentityV1::MemberRelation
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1::MemberRelation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb
Overview
Message representing a transitive membership of a group.
Instance Attribute Summary collapse
-
#member ⇒ String
Resource name for this member.
-
#preferred_member_key ⇒ Array<Google::Apis::CloudidentityV1::EntityKey>
Entity key has an id and a namespace.
-
#relation_type ⇒ String
The relation between the group and the transitive member.
-
#roles ⇒ Array<Google::Apis::CloudidentityV1::TransitiveMembershipRole>
The membership role details (i.e name of role and expiry time).
Instance Method Summary collapse
-
#initialize(**args) ⇒ MemberRelation
constructor
A new instance of MemberRelation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MemberRelation
Returns a new instance of MemberRelation.
2473 2474 2475 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#member ⇒ String
Resource name for this member.
Corresponds to the JSON property member
2455 2456 2457 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2455 def member @member end |
#preferred_member_key ⇒ Array<Google::Apis::CloudidentityV1::EntityKey>
Entity key has an id and a namespace. In case of discussion forums, the id
will be an email address without a namespace.
Corresponds to the JSON property preferredMemberKey
2461 2462 2463 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2461 def preferred_member_key @preferred_member_key end |
#relation_type ⇒ String
The relation between the group and the transitive member.
Corresponds to the JSON property relationType
2466 2467 2468 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2466 def relation_type @relation_type end |
#roles ⇒ Array<Google::Apis::CloudidentityV1::TransitiveMembershipRole>
The membership role details (i.e name of role and expiry time).
Corresponds to the JSON property roles
2471 2472 2473 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2471 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2478 2479 2480 2481 2482 2483 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2478 def update!(**args) @member = args[:member] if args.key?(:member) @preferred_member_key = args[:preferred_member_key] if args.key?(:preferred_member_key) @relation_type = args[:relation_type] if args.key?(:relation_type) @roles = args[:roles] if args.key?(:roles) end |