Class: Google::Apis::CloudidentityV1::Membership

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb

Overview

A membership within the Cloud Identity Groups API. A Membership defines a relationship between a Group and an entity belonging to that Group, referred to as a "member".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Membership

Returns a new instance of Membership.



2567
2568
2569
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the Membership was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2528
2529
2530
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2528

def create_time
  @create_time
end

#delivery_settingString

Output only. Delivery setting associated with the membership. Corresponds to the JSON property deliverySetting

Returns:

  • (String)


2533
2534
2535
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2533

def delivery_setting
  @delivery_setting
end

#nameString

Output only. The resource name of the Membership. Shall be of the form groups/group/ memberships/membership`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2540
2541
2542
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2540

def name
  @name
end

#preferred_member_keyGoogle::Apis::CloudidentityV1::EntityKey

A unique identifier for an entity in the Cloud Identity Groups API. An entity can represent either a group with an optional namespace or a user without a namespace. The combination of id and namespace must be unique; however, the same id can be used with different namespaces. Corresponds to the JSON property preferredMemberKey



2548
2549
2550
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2548

def preferred_member_key
  @preferred_member_key
end

#rolesArray<Google::Apis::CloudidentityV1::MembershipRole>

The MembershipRoles that apply to the Membership. If unspecified, defaults to a single MembershipRole with name MEMBER. Must not contain duplicate MembershipRoles with the same name. Corresponds to the JSON property roles



2555
2556
2557
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2555

def roles
  @roles
end

#typeString

Output only. The type of the membership. Corresponds to the JSON property type

Returns:

  • (String)


2560
2561
2562
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2560

def type
  @type
end

#update_timeString

Output only. The time when the Membership was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2565
2566
2567
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2565

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2572
2573
2574
2575
2576
2577
2578
2579
2580
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2572

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delivery_setting = args[:delivery_setting] if args.key?(:delivery_setting)
  @name = args[:name] if args.key?(:name)
  @preferred_member_key = args[:preferred_member_key] if args.key?(:preferred_member_key)
  @roles = args[:roles] if args.key?(:roles)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end