Class: Google::Apis::CloudidentityV1::ModifyMembershipRolesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb

Overview

The request message for MembershipsService.ModifyMembershipRoles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModifyMembershipRolesRequest

Returns a new instance of ModifyMembershipRolesRequest.



2751
2752
2753
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_rolesArray<Google::Apis::CloudidentityV1::MembershipRole>

The MembershipRoles to be added. Adding or removing roles in the same request as updating roles is not supported. Must not be set if update_roles_params is set. Corresponds to the JSON property addRoles



2733
2734
2735
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2733

def add_roles
  @add_roles
end

#remove_rolesArray<String>

The names of the MembershipRoles to be removed. Adding or removing roles in the same request as updating roles is not supported. It is not possible to remove the MEMBER MembershipRole. If you wish to delete a Membership, call MembershipsService.DeleteMembership instead. Must not contain MEMBER. Must not be set if update_roles_params is set. Corresponds to the JSON property removeRoles

Returns:

  • (Array<String>)


2742
2743
2744
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2742

def remove_roles
  @remove_roles
end

#update_roles_paramsArray<Google::Apis::CloudidentityV1::UpdateMembershipRolesParams>

The MembershipRoles to be updated. Updating roles in the same request as adding or removing roles is not supported. Must not be set if either add_roles or remove_roles is set. Corresponds to the JSON property updateRolesParams



2749
2750
2751
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2749

def update_roles_params
  @update_roles_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2756
2757
2758
2759
2760
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2756

def update!(**args)
  @add_roles = args[:add_roles] if args.key?(:add_roles)
  @remove_roles = args[:remove_roles] if args.key?(:remove_roles)
  @update_roles_params = args[:update_roles_params] if args.key?(:update_roles_params)
end