Class: Google::Apis::CloudidentityV1::PolicyQuery
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1::PolicyQuery
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb
Overview
PolicyQuery
Instance Attribute Summary collapse
-
#group ⇒ String
Immutable.
-
#org_unit ⇒ String
Required.
-
#query ⇒ String
Immutable.
-
#sort_order ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PolicyQuery
constructor
A new instance of PolicyQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PolicyQuery
Returns a new instance of PolicyQuery.
3017 3018 3019 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ String
Immutable. The group that the query applies to. This field is only set if
there is a single value for group that satisfies all clauses of the query. If
no group applies, this will be the empty string.
Corresponds to the JSON property group
2984 2985 2986 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2984 def group @group end |
#org_unit ⇒ String
Required. Immutable. Non-empty default. The OrgUnit the query applies to. This
field is only set if there is a single value for org_unit that satisfies all
clauses of the query.
Corresponds to the JSON property orgUnit
2991 2992 2993 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2991 def org_unit @org_unit end |
#query ⇒ String
Immutable. The CEL query that defines which entities the Policy applies to (ex.
a User entity). For details about CEL see https://opensource.google.com/
projects/cel. The OrgUnits the Policy applies to are represented by a clause
like so: entity.org_units.exists(org_unit, org_unit.org_unit_id == orgUnitId('
orgUnitId')) The Group the Policy applies to are represented by a clause like
so: entity.groups.exists(group, group.group_id == groupId('groupId')) The
Licenses the Policy applies to are represented by a clause like so: entity.
licenses.exists(license, license in ['/product/productId/sku/skuId']) **
Note:** The licenses clause is not supported in mutate endpoints. The above
clauses can be present in any combination, and used in conjunction with the &&,
|| and ! operators. The org_unit and group fields below are helper fields
that contain the corresponding value(s) as the query to make the query easier
to use.
Corresponds to the JSON property query
3008 3009 3010 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3008 def query @query end |
#sort_order ⇒ Float
Output only. The decimal sort order of this PolicyQuery. The value is relative
to all other policies with the same setting type for the customer. (There are
no duplicates within this set).
Corresponds to the JSON property sortOrder
3015 3016 3017 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3015 def sort_order @sort_order end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3022 3023 3024 3025 3026 3027 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3022 def update!(**args) @group = args[:group] if args.key?(:group) @org_unit = args[:org_unit] if args.key?(:org_unit) @query = args[:query] if args.key?(:query) @sort_order = args[:sort_order] if args.key?(:sort_order) end |