Class: Google::Apis::CloudidentityV1::UpdateInboundOidcSsoProfileOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1::UpdateInboundOidcSsoProfileOperationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb
Overview
LRO response metadata for InboundOidcSsoProfilesService. UpdateInboundOidcSsoProfile.
Instance Attribute Summary collapse
-
#state ⇒ String
State of this Operation Will be "awaiting-multi-party-approval" when the operation is deferred due to the target customer having enabled Multi-party approval for sensitive actions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateInboundOidcSsoProfileOperationMetadata
constructor
A new instance of UpdateInboundOidcSsoProfileOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateInboundOidcSsoProfileOperationMetadata
Returns a new instance of UpdateInboundOidcSsoProfileOperationMetadata.
3450 3451 3452 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state ⇒ String
State of this Operation Will be "awaiting-multi-party-approval" when the
operation is deferred due to the target customer having enabled Multi-party
approval for sensitive actions.
Corresponds to the JSON property state
3448 3449 3450 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3448 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3455 3456 3457 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3455 def update!(**args) @state = args[:state] if args.key?(:state) end |