Class: Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1Device
- Inherits:
-
Object
- Object
- Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1Device
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb
Overview
A Device within the Cloud Identity Devices API. Represents a Device known to Google Cloud, independent of the device ownership, type, and whether it is assigned or in use by a user.
Instance Attribute Summary collapse
-
#android_specific_attributes ⇒ Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1AndroidAttributes
Resource representing the Android specific attributes of a Device.
-
#asset_tag ⇒ String
Asset tag of the device.
-
#baseband_version ⇒ String
Output only.
-
#bootloader_version ⇒ String
Output only.
-
#brand ⇒ String
Output only.
-
#build_number ⇒ String
Output only.
-
#compromised_state ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#device_id ⇒ String
Unique identifier for the device.
-
#device_type ⇒ String
Output only.
-
#enabled_developer_options ⇒ Boolean
(also: #enabled_developer_options?)
Output only.
-
#enabled_usb_debugging ⇒ Boolean
(also: #enabled_usb_debugging?)
Output only.
-
#encryption_state ⇒ String
Output only.
-
#endpoint_verification_specific_attributes ⇒ Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1EndpointVerificationSpecificAttributes
Resource representing the Endpoint Verification-specific attributes of a device.
-
#hostname ⇒ String
Host name of the device.
-
#imei ⇒ String
Output only.
-
#kernel_version ⇒ String
Output only.
-
#last_sync_time ⇒ String
Most recent time when device synced with this service.
-
#management_state ⇒ String
Output only.
-
#manufacturer ⇒ String
Output only.
-
#meid ⇒ String
Output only.
-
#model ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#network_operator ⇒ String
Output only.
-
#os_version ⇒ String
Output only.
-
#other_accounts ⇒ Array<String>
Output only.
-
#owner_type ⇒ String
Output only.
-
#release_version ⇒ String
Output only.
-
#security_patch_time ⇒ String
Output only.
-
#serial_number ⇒ String
Serial Number of device.
-
#unified_device_id ⇒ String
Output only.
-
#wifi_mac_addresses ⇒ Array<String>
WiFi MAC addresses of device.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1Device
constructor
A new instance of GoogleAppsCloudidentityDevicesV1Device.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAppsCloudidentityDevicesV1Device
Returns a new instance of GoogleAppsCloudidentityDevicesV1Device.
1385 1386 1387 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_specific_attributes ⇒ Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1AndroidAttributes
Resource representing the Android specific attributes of a Device.
Corresponds to the JSON property androidSpecificAttributes
1215 1216 1217 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1215 def android_specific_attributes @android_specific_attributes end |
#asset_tag ⇒ String
Asset tag of the device.
Corresponds to the JSON property assetTag
1220 1221 1222 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1220 def asset_tag @asset_tag end |
#baseband_version ⇒ String
Output only. Baseband version of the device.
Corresponds to the JSON property basebandVersion
1225 1226 1227 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1225 def baseband_version @baseband_version end |
#bootloader_version ⇒ String
Output only. Device bootloader version. Example: 0.6.7.
Corresponds to the JSON property bootloaderVersion
1230 1231 1232 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1230 def bootloader_version @bootloader_version end |
#brand ⇒ String
Output only. Device brand. Example: Samsung.
Corresponds to the JSON property brand
1235 1236 1237 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1235 def brand @brand end |
#build_number ⇒ String
Output only. Build number of the device.
Corresponds to the JSON property buildNumber
1240 1241 1242 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1240 def build_number @build_number end |
#compromised_state ⇒ String
Output only. Represents whether the Device is compromised.
Corresponds to the JSON property compromisedState
1245 1246 1247 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1245 def compromised_state @compromised_state end |
#create_time ⇒ String
Output only. When the Company-Owned device was imported. This field is empty
for BYOD devices.
Corresponds to the JSON property createTime
1251 1252 1253 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1251 def create_time @create_time end |
#device_id ⇒ String
Unique identifier for the device.
Corresponds to the JSON property deviceId
1256 1257 1258 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1256 def device_id @device_id end |
#device_type ⇒ String
Output only. Type of device.
Corresponds to the JSON property deviceType
1261 1262 1263 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1261 def device_type @device_type end |
#enabled_developer_options ⇒ Boolean Also known as: enabled_developer_options?
Output only. Whether developer options is enabled on device.
Corresponds to the JSON property enabledDeveloperOptions
1266 1267 1268 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1266 def @enabled_developer_options end |
#enabled_usb_debugging ⇒ Boolean Also known as: enabled_usb_debugging?
Output only. Whether USB debugging is enabled on device.
Corresponds to the JSON property enabledUsbDebugging
1272 1273 1274 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1272 def enabled_usb_debugging @enabled_usb_debugging end |
#encryption_state ⇒ String
Output only. Device encryption state.
Corresponds to the JSON property encryptionState
1278 1279 1280 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1278 def encryption_state @encryption_state end |
#endpoint_verification_specific_attributes ⇒ Google::Apis::CloudidentityV1::GoogleAppsCloudidentityDevicesV1EndpointVerificationSpecificAttributes
Resource representing the Endpoint Verification-specific attributes of a device.
Corresponds to the JSON property endpointVerificationSpecificAttributes
1284 1285 1286 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1284 def endpoint_verification_specific_attributes @endpoint_verification_specific_attributes end |
#hostname ⇒ String
Host name of the device.
Corresponds to the JSON property hostname
1289 1290 1291 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1289 def hostname @hostname end |
#imei ⇒ String
Output only. IMEI number of device if GSM device; empty otherwise.
Corresponds to the JSON property imei
1294 1295 1296 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1294 def imei @imei end |
#kernel_version ⇒ String
Output only. Kernel version of the device.
Corresponds to the JSON property kernelVersion
1299 1300 1301 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1299 def kernel_version @kernel_version end |
#last_sync_time ⇒ String
Most recent time when device synced with this service.
Corresponds to the JSON property lastSyncTime
1304 1305 1306 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1304 def last_sync_time @last_sync_time end |
#management_state ⇒ String
Output only. Management state of the device
Corresponds to the JSON property managementState
1309 1310 1311 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1309 def management_state @management_state end |
#manufacturer ⇒ String
Output only. Device manufacturer. Example: Motorola.
Corresponds to the JSON property manufacturer
1314 1315 1316 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1314 def manufacturer @manufacturer end |
#meid ⇒ String
Output only. MEID number of device if CDMA device; empty otherwise.
Corresponds to the JSON property meid
1319 1320 1321 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1319 def meid @meid end |
#model ⇒ String
Output only. Model name of device. Example: Pixel 3.
Corresponds to the JSON property model
1324 1325 1326 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1324 def model @model end |
#name ⇒ String
Output only. Resource name of the Device in format: devices/device`, where device is
the unique id assigned to the Device. Important: Device API scopes require
that you use domain-wide delegation to access the API. For more information,
see [Set up the Devices API](https://cloud.google.com/identity/docs/how-to/
setup-devices).
Corresponds to the JSON propertyname`
1334 1335 1336 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1334 def name @name end |
#network_operator ⇒ String
Output only. Mobile or network operator of device, if available.
Corresponds to the JSON property networkOperator
1339 1340 1341 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1339 def network_operator @network_operator end |
#os_version ⇒ String
Output only. OS version of the device. Example: Android 8.1.0.
Corresponds to the JSON property osVersion
1344 1345 1346 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1344 def os_version @os_version end |
#other_accounts ⇒ Array<String>
Output only. Domain name for Google accounts on device. Type for other
accounts on device. On Android, will only be populated if |ownership_privilege|
is |PROFILE_OWNER| or |DEVICE_OWNER|. Does not include the account signed in
to the device policy app if that account's domain has only one account.
Examples: "com.example", "xyz.com".
Corresponds to the JSON property otherAccounts
1353 1354 1355 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1353 def other_accounts @other_accounts end |
#owner_type ⇒ String
Output only. Whether the device is owned by the company or an individual
Corresponds to the JSON property ownerType
1358 1359 1360 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1358 def owner_type @owner_type end |
#release_version ⇒ String
Output only. OS release version. Example: 6.0.
Corresponds to the JSON property releaseVersion
1363 1364 1365 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1363 def release_version @release_version end |
#security_patch_time ⇒ String
Output only. OS security patch update time on device.
Corresponds to the JSON property securityPatchTime
1368 1369 1370 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1368 def security_patch_time @security_patch_time end |
#serial_number ⇒ String
Serial Number of device. Example: HT82V1A01076.
Corresponds to the JSON property serialNumber
1373 1374 1375 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1373 def serial_number @serial_number end |
#unified_device_id ⇒ String
Output only. Unified device id of the device.
Corresponds to the JSON property unifiedDeviceId
1378 1379 1380 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1378 def unified_device_id @unified_device_id end |
#wifi_mac_addresses ⇒ Array<String>
WiFi MAC addresses of device.
Corresponds to the JSON property wifiMacAddresses
1383 1384 1385 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1383 def wifi_mac_addresses @wifi_mac_addresses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 |
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 1390 def update!(**args) @android_specific_attributes = args[:android_specific_attributes] if args.key?(:android_specific_attributes) @asset_tag = args[:asset_tag] if args.key?(:asset_tag) @baseband_version = args[:baseband_version] if args.key?(:baseband_version) @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version) @brand = args[:brand] if args.key?(:brand) @build_number = args[:build_number] if args.key?(:build_number) @compromised_state = args[:compromised_state] if args.key?(:compromised_state) @create_time = args[:create_time] if args.key?(:create_time) @device_id = args[:device_id] if args.key?(:device_id) @device_type = args[:device_type] if args.key?(:device_type) @enabled_developer_options = args[:enabled_developer_options] if args.key?(:enabled_developer_options) @enabled_usb_debugging = args[:enabled_usb_debugging] if args.key?(:enabled_usb_debugging) @encryption_state = args[:encryption_state] if args.key?(:encryption_state) @endpoint_verification_specific_attributes = args[:endpoint_verification_specific_attributes] if args.key?(:endpoint_verification_specific_attributes) @hostname = args[:hostname] if args.key?(:hostname) @imei = args[:imei] if args.key?(:imei) @kernel_version = args[:kernel_version] if args.key?(:kernel_version) @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time) @management_state = args[:management_state] if args.key?(:management_state) @manufacturer = args[:manufacturer] if args.key?(:manufacturer) @meid = args[:meid] if args.key?(:meid) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @network_operator = args[:network_operator] if args.key?(:network_operator) @os_version = args[:os_version] if args.key?(:os_version) @other_accounts = args[:other_accounts] if args.key?(:other_accounts) @owner_type = args[:owner_type] if args.key?(:owner_type) @release_version = args[:release_version] if args.key?(:release_version) @security_patch_time = args[:security_patch_time] if args.key?(:security_patch_time) @serial_number = args[:serial_number] if args.key?(:serial_number) @unified_device_id = args[:unified_device_id] if args.key?(:unified_device_id) @wifi_mac_addresses = args[:wifi_mac_addresses] if args.key?(:wifi_mac_addresses) end |