Class: Google::Apis::CloudidentityV1::PolicyQuery

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudidentity_v1/classes.rb,
lib/google/apis/cloudidentity_v1/representations.rb,
lib/google/apis/cloudidentity_v1/representations.rb

Overview

PolicyQuery

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyQuery

Returns a new instance of PolicyQuery.



3016
3017
3018
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

Immutable. The group that the query applies to. This field is only set if there is a single value for group that satisfies all clauses of the query. If no group applies, this will be the empty string. Corresponds to the JSON property group

Returns:

  • (String)


2984
2985
2986
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2984

def group
  @group
end

#org_unitString

Required. Immutable. Non-empty default. The OrgUnit the query applies to. This field is only set if there is a single value for org_unit that satisfies all clauses of the query. Corresponds to the JSON property orgUnit

Returns:

  • (String)


2991
2992
2993
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 2991

def org_unit
  @org_unit
end

#queryString

Immutable. The CEL query that defines which entities the Policy applies to (ex. a User entity). For details about CEL see https://opensource.google.com/ projects/cel. The OrgUnits the Policy applies to are represented by a clause like so: entity.org_units.exists(org_unit, org_unit.org_unit_id == orgUnitId(' orgUnitId')) The Group the Policy applies to are represented by a clause like so: entity.groups.exists(group, group.group_id == groupId('groupId')) The Licenses the Policy applies to are represented by a clause like so: entity. licenses.exists(license, license in ['/product/productId/sku/skuId']) The above clauses can be present in any combination, and used in conjunction with the &&, || and ! operators. The org_unit and group fields below are helper fields that contain the corresponding value(s) as the query to make the query easier to use. Corresponds to the JSON property query

Returns:

  • (String)


3007
3008
3009
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3007

def query
  @query
end

#sort_orderFloat

Output only. The decimal sort order of this PolicyQuery. The value is relative to all other policies with the same setting type for the customer. (There are no duplicates within this set). Corresponds to the JSON property sortOrder

Returns:

  • (Float)


3014
3015
3016
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3014

def sort_order
  @sort_order
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3021
3022
3023
3024
3025
3026
# File 'lib/google/apis/cloudidentity_v1/classes.rb', line 3021

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @org_unit = args[:org_unit] if args.key?(:org_unit)
  @query = args[:query] if args.key?(:query)
  @sort_order = args[:sort_order] if args.key?(:sort_order)
end